using System;
using System.Collections.Generic;
using System.Text;
using IC.PhotoController;
using IC.PhotoController.Filter;
using System.Drawing;
using System.Drawing.Drawing2D;

namespace PhotoControllerDemo
{
    class FastEdgeDetectFilter : BaseFilter  
    {
        /// <summary>
        /// A fast edge detect algorithm
        /// the formula is
        ///     new [x,y] = old[x,y] + (Z/2 - old[x+2, y+2])
        /// </summary>
        protected override void ApplyFilter()
        {
            // store the bitmap information first
            int width = this.Bounds.Width;
            int height = this.Bounds.Height;

            for (int x = 0; x < width; x++)
            {
                for (int y = 0; y < height; y++)
                {
                    if (x + 2 < width && y + 2 < height)
                    {
                        Color offset = getPixel(x + 2, y + 2);
                        Color current = getPixel(x, y);

                        // apply the algorithm
                        byte red = (byte)(current.R + (128 - offset.R));
                        byte green = (byte)(current.G + (128 - offset.G));
                        byte blue = (byte)(current.B + (128 - offset.B));

                        Color newColor = Color.FromArgb(red,green,blue);
                        setPixel(x, y, newColor);
                    }
                }
            }
        }

    }

    /// <summary>
    /// Perform the mirro filter, actually it is doing a horizontal flip
    /// </summary>
    class MirrorFilter : BaseOffsetFilter
    {
        protected override void transform(float x, float y, out float new_x, out float new_y)
        {
            new_x = Bounds.Width - x;
            new_y = y;
        }
    }

    /// <summary>
    /// Performs the posterize filter
    /// </summary>
    class PosterizeFilter : BaseColorFilter
    {
        private float _level = 10;

        public float Level
        {
            get { return _level; }
            set { if (value > 0 && value <= 100) _level = value; }
        }

        /// <summary>
        /// This method change the color at every pixel to a new color inorder to simulate a posterize effect.
        /// This effect is not tested carefully about the parameter range. It just tends to demonstrates
        /// how to customize a filter by inheriting the BaseColorFilter
        /// </summary>
        /// <param name="oldColor"></param>
        /// <param name="newColor"></param>
        protected override void transformColor(Color oldColor, out Color newColor)
        {
            byte red = (byte)( Math.Round(oldColor.R / _level) * _level) ;
            byte blue = (byte)(Math.Round(oldColor.B / _level) * _level);
            byte green = (byte)(Math.Round(oldColor.G / _level) * _level);
            newColor = Color.FromArgb(oldColor.A, red, blue, green);
        }
    }
}
