using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace PhotoControllerDemo
{
    public partial class frmBomb : Form
    {
        public frmMain parent = null;

        public frmBomb()
        {
            InitializeComponent();
        }

        private void tbCentreX_Scroll(object sender, EventArgs e)
        {
            this.labCentreX.Text = "Centre X (" + tbCentreX.Value.ToString() + ")";
            UpdatePreview();
        }

        private void tbCentreY_Scroll(object sender, EventArgs e)
        {
            this.labCentreY.Text = "Centre X (" + tbCentreY.Value.ToString() + ")";
            UpdatePreview();
        }

        private void tbRadius_Scroll(object sender, EventArgs e)
        {
            this.labRadius.Text = "Radius (" + tbRadius.Value.ToString() + ")";
            UpdatePreview();
        }

        private void tbWaveLength_Scroll(object sender, EventArgs e)
        {
            labWave.Text = "Wave (" + tbWaveLength.Value.ToString() + ")";
            UpdatePreview();
        }

        private void tbAmplitude_Scroll(object sender, EventArgs e)
        {
            labAmplitude.Text = "Amplitude (" + tbAmplitude.Value.ToString() + ")";
            UpdatePreview();
        }

        private void UpdatePreview()
        {
            if (!chkPreview.Checked) return;

            IC.PhotoController.Filter.BombWaveFilter filter = new IC.PhotoController.Filter.BombWaveFilter();
            filter.Amplitude = this.tbAmplitude.Value;
            filter.Centre = new PointF(this.tbCentreX.Value, this.tbCentreY.Value);
            filter.Radius = this.tbRadius.Value;
            filter.WaveLength = this.tbWaveLength.Value;
            filter.Edge = (IC.PhotoController.EdgeType)this.comboBox1.SelectedIndex;

            IC.PhotoController.Controller pc = new IC.PhotoController.Controller(backupImg);
            parent.pic.Image.Dispose();
            parent.pic.Image = pc.Filter(filter);
            pc.Dispose();
        }

        System.Drawing.Bitmap backupImg = null;

        private void frmBomb_Load(object sender, EventArgs e)
        {
            this.comboBox1.SelectedIndex = 1;

            // save a backup image 
            backupImg = new Bitmap(parent.pic.Image);
            Update();
        }

        private void btCancel_Click(object sender, EventArgs e)
        {
            // reset the parent image
            parent.pic.Image = (Image) backupImg.Clone();
            timer1.Enabled = false;
            this.DialogResult = DialogResult.Cancel;
        }

        private void frmBomb_FormClosed(object sender, FormClosedEventArgs e)
        {
            //release resource
            if (backupImg != null) backupImg.Dispose();
        }

        bool running = false;
        float increment = 1.0f;
        private void btAuto_Click(object sender, EventArgs e)
        {
            if (running)
            {
                btAuto.Text = "Auto";
                timer1.Enabled = false;
                running = false;
                return;
            }
            btAuto.Text = "Stop";
            timer1.Enabled = true;
            running = true;
            increment = 1.0f;
        }

        // the timer will increase wavelength by 3 every 5 millisecond
        // this animation will be similar to a bomb blows from the center
        private void timer1_Tick(object sender, EventArgs e)
        {
            if (increment >= Math.Min(backupImg.Width, backupImg.Height))
            {
                // enough bomb
                timer1.Enabled = false;
                running = false;
                btAuto.Text = "Auto";
                return;
            }

            IC.PhotoController.Filter.BombWaveFilter filter = new IC.PhotoController.Filter.BombWaveFilter();
            filter.Amplitude = this.tbAmplitude.Value;
            filter.Centre = new PointF(50, 50);
            filter.Radius = 5; // use a small number, start bombing from a smaller area
            increment += 3;
            filter.WaveLength = increment ;
            filter.Edge = (IC.PhotoController.EdgeType)this.comboBox1.SelectedIndex;

            IC.PhotoController.Controller pc = new IC.PhotoController.Controller(backupImg);
            parent.pic.Image.Dispose();
            parent.pic.Image = pc.Filter(filter);
            parent.pic.Update();
            pc.Dispose();
        }

        private void btOK_Click(object sender, EventArgs e)
        {
            parent.pic.Image = (Image)backupImg.Clone();
            this.DialogResult = DialogResult.OK;
        }
    }
}