using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;

namespace PhotoControllerDemo
{
    using System.Drawing.Drawing2D;
    using IC.PhotoController.Border;

    public partial class frmGradientBorder : Form
    {
        public frmGradientBorder()
        {
            InitializeComponent();
            _builder = new BorderBuilder();
        }

        private BorderBuilder _builder;

        public BorderBuilder BorderBuilder
        {
            get { return _builder; }
        }

        private void btOK_Click(object sender, EventArgs e)
        {
            // build the BorderBuilder object
            _builder.Length = this.trackLength.Value;

            BorderAlignment alignment = BorderAlignment.NONE;

            if (chkEAST.Checked)
                alignment = BorderAlignment.EAST;
            if (chkSOUTH.Checked)
                alignment = alignment | BorderAlignment.SOUTH;
            if (chkWEST.Checked)
                alignment = alignment | BorderAlignment.WEST;
            if (chkNORTH.Checked)
                alignment = alignment | BorderAlignment.NORTH;
            if (chkALL.Checked)
                alignment = BorderAlignment.ALL;

            _builder.Alignment = alignment;

            int brushLength = (int)numBrushLength.Value;
            Rectangle rect = new Rectangle(0, 0, brushLength, brushLength);
            LinearGradientMode mode = (LinearGradientMode)this.cboxGradientMode.SelectedIndex;

            LinearGradientBrush brush = new LinearGradientBrush(rect, btColor.BackColor, btColor2.BackColor,mode);
            brush.WrapMode = WrapMode.Tile;
            _builder.Brush = brush;

            this.DialogResult = DialogResult.OK;
        }

        private void frmGradientBorder_Load(object sender, EventArgs e)
        {
            string[] bs;
            bs = Enum.GetNames(typeof(LinearGradientMode));
            foreach (string sbs in bs)
            {
                cboxGradientMode.Items.Add(sbs);
            }
            chkALL.Checked = true;
            cboxGradientMode.SelectedIndex = 1;
            numBrushLength.Value = trackLength.Value;
        }

        private void trackLength_Scroll(object sender, EventArgs e)
        {
            this.lbeLength.Text = "Border length - " + trackLength.Value.ToString();
            this.numBrushLength.Value = trackLength.Value;
        }

        private void chkEAST_CheckedChanged(object sender, EventArgs e)
        {
            if (chkALL.CheckState == CheckState.Checked && (sender as CheckBox).CheckState == CheckState.Checked)
                chkALL.CheckState = CheckState.Unchecked;
        }

        private void chkALL_CheckedChanged(object sender, EventArgs e)
        {
            if (chkALL.CheckState == CheckState.Checked)
                chkEAST.Checked = chkSOUTH.Checked = chkWEST.Checked = chkNORTH.Checked = false;
        }

        private void btColor_Click(object sender, EventArgs e)
        {
            if (dlgColor.ShowDialog() == DialogResult.OK)
            {
                btColor.BackColor = dlgColor.Color;
            }
        }

        private void btColor2_Click(object sender, EventArgs e)
        {
            if (dlgColor.ShowDialog() == DialogResult.OK)
            {
                btColor2.BackColor = dlgColor.Color;
            }
        }
    }
}