using System;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Windows.Forms;
using IC.PhotoController.Border;

namespace PhotoControllerDemo
{
    public partial class frmTextureBorder : Form
    {
        public frmTextureBorder()
        {
            InitializeComponent();

            _builder = new BorderBuilder();
        }

        private BorderBuilder _builder;

        public BorderBuilder BorderBuilder
        {
            get { return _builder; }
        }

        private void btOK_Click(object sender, EventArgs e)
        {
            if (picTexture.Image == null)
            {
                MessageBox.Show("Please select a texture image first.");
                return;
            }

            // build the BorderBuilder object
            _builder.Length = this.trackLength.Value;

            BorderAlignment alignment = BorderAlignment.NONE;

            if (chkEAST.Checked)
                alignment = BorderAlignment.EAST;
            if (chkSOUTH.Checked)
                alignment = alignment | BorderAlignment.SOUTH;
            if (chkWEST.Checked)
                alignment = alignment | BorderAlignment.WEST;
            if (chkNORTH.Checked)
                alignment = alignment | BorderAlignment.NORTH;
            if (chkALL.Checked)
                alignment = BorderAlignment.ALL;

            _builder.Alignment = alignment;

            // build texture brush
            TextureBrush brush = new TextureBrush(picTexture.Image);
            brush.WrapMode = WrapMode.Tile;

            _builder.Brush = brush;

            this.DialogResult = DialogResult.OK;
        }

        private void trackLength_Scroll(object sender, EventArgs e)
        {
            this.lbeLength.Text = "Border length - " + trackLength.Value.ToString();
        }

        private void chkALL_CheckedChanged(object sender, EventArgs e)
        {
            if (chkALL.CheckState == CheckState.Checked)
                chkEAST.Checked = chkSOUTH.Checked = chkWEST.Checked = chkNORTH.Checked = false;
        }

        private void picTexture_Click(object sender, EventArgs e)
        {
            if (dlgOpen.ShowDialog() == DialogResult.OK)
            {
                picTexture.Image = Image.FromFile(dlgOpen.FileName);
            }
        }

        private void frmTextureBorder_Load(object sender, EventArgs e)
        {
            chkALL.Checked = true;
        }

        private void chkEAST_CheckedChanged(object sender, EventArgs e)
        {
            if (chkALL.CheckState == CheckState.Checked && (sender as CheckBox).CheckState == CheckState.Checked)
                chkALL.CheckState = CheckState.Unchecked;
        }
    }
}